==> dapware-ram-spring-boot-autoconfigure-2.7.30-sources.jar: com/digiwin/dap/middle/autoconfigure/config/RamCoreConfiguration.java <==
package com.digiwin.dap.middle.autoconfigure.config;

import com.digiwin.dap.middle.autoconfigure.condition.IamV1Condition;
import com.digiwin.dap.middle.autoconfigure.properties.RamProperties;
import com.digiwin.dap.middle.ram.constant.RamConstant;
import com.digiwin.dap.middle.ram.domain.request.AccessUser;
import com.digiwin.dap.middle.ram.filter.RamV1AccessCheckFilter;
import com.digiwin.dap.middle.ram.service.core.RamCoreService;
import com.digiwin.dap.middle.ram.support.DefaultRamHandlerSupport;
import com.digiwin.dap.middle.ram.support.RamHandlerSupport;
import com.digiwin.dap.middle.ram.support.security.auth.AuthPolicyHandler;
import com.digiwin.dap.middle.ram.support.security.auth.AuthPolicyHandlerComposite;
import com.digiwin.dap.middle.ram.support.security.path.PathPolicyHandler;
import com.digiwin.dap.middle.ram.support.security.path.PathPolicyHandlerComposite;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.SearchStrategy;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Conditional;
import org.springframework.context.annotation.Configuration;

import javax.servlet.Filter;

/**
 * 核心服务
 * 拦截器：普通策略
 * 拦截器：授权检查
 * 过滤器：服务权限
 *
 * @author fobgochod
 */
@Configuration
@EnableConfigurationProperties(RamProperties.class)
public class RamCoreConfiguration {

    private final RamProperties properties;

    public RamCoreConfiguration(RamProperties properties) {
        this.properties = properties;
    }

    @Bean
    @ConditionalOnMissingBean(value = RamHandlerSupport.class, search = SearchStrategy.CURRENT)
    public RamHandlerSupport ramHandlerSupport() {
        return new DefaultRamHandlerSupport();
    }

    @Bean
    @ConditionalOnBean(value = {RamCoreService.class, RamHandlerSupport.class})
    public PathPolicyHandlerComposite pathPolicyHandler(RamCoreService ramCoreService, RamHandlerSupport ramHandlerSupport) {
        return new PathPolicyHandlerComposite(ramCoreService, ramHandlerSupport, properties.isFunction());
    }

    @Bean
    @ConditionalOnBean(value = {RamCoreService.class, RamHandlerSupport.class})
    public AuthPolicyHandlerComposite authPolicyHandler(RamCoreService ramCoreService, RamHandlerSupport ramHandlerSupport) {
        return new AuthPolicyHandlerComposite(ramCoreService, ramHandlerSupport);
    }

    @Bean
    @ConditionalOnBean(value = {PathPolicyHandler.class, AuthPolicyHandler.class})
    @Conditional(IamV1Condition.class)
    public FilterRegistrationBean<Filter> ramAccessCheckRegistration(PathPolicyHandler<AccessUser> pathPolicyHandler, AuthPolicyHandler authPolicyHandler) {
        FilterRegistrationBean<Filter> registrationBean = new FilterRegistrationBean<>();
        RamV1AccessCheckFilter filter = new RamV1AccessCheckFilter(pathPolicyHandler, authPolicyHandler);
        registrationBean.setFilter(filter);
        registrationBean.setOrder(filter.getOrder());
        registrationBean.addUrlPatterns(RamConstant.DEFAULT_URL_MAPPINGS);
        registrationBean.setAsyncSupported(true);
        return registrationBean;
    }
}

==> dapware-ram-spring-boot-autoconfigure-3.5.0-20251204.074836-11-sources.jar: com/digiwin/dap/middle/autoconfigure/config/RamCoreConfiguration.java <==
package com.digiwin.dap.middle.autoconfigure.config;

import com.digiwin.dap.middle.autoconfigure.condition.IamV1Condition;
import com.digiwin.dap.middle.autoconfigure.properties.RamProperties;
import com.digiwin.dap.middle.ram.constant.RamConstant;
import com.digiwin.dap.middle.ram.domain.request.AccessUser;
import com.digiwin.dap.middle.ram.filter.RamV1AccessCheckFilter;
import com.digiwin.dap.middle.ram.service.core.RamCoreService;
import com.digiwin.dap.middle.ram.support.iam.DefaultRamCacheSupport;
import com.digiwin.dap.middle.ram.support.iam.DefaultRamHandlerSupport;
import com.digiwin.dap.middle.ram.support.RamCacheSupport;
import com.digiwin.dap.middle.ram.support.RamHandlerSupport;
import com.digiwin.dap.middle.ram.support.security.auth.AuthPolicyHandler;
import com.digiwin.dap.middle.ram.support.security.auth.AuthPolicyHandlerComposite;
import com.digiwin.dap.middle.ram.support.security.path.PathPolicyHandler;
import com.digiwin.dap.middle.ram.support.security.path.PathPolicyHandlerComposite;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.SearchStrategy;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Conditional;
import org.springframework.context.annotation.Configuration;

import jakarta.servlet.Filter;

/**
 * 核心服务
 * 拦截器：普通策略
 * 拦截器：授权检查
 * 过滤器：服务权限
 *
 * @author fobgochod
 */
@Configuration
@EnableConfigurationProperties(RamProperties.class)
public class RamCoreConfiguration {

    private final RamProperties properties;

    public RamCoreConfiguration(RamProperties properties) {
        this.properties = properties;
    }

    @Bean
    @ConditionalOnMissingBean(value = RamCacheSupport.class, search = SearchStrategy.CURRENT)
    public RamCacheSupport ramCacheSupport() {
        return new DefaultRamCacheSupport();
    }

    @Bean
    @ConditionalOnBean(value = RamCacheSupport.class)
    @ConditionalOnMissingBean(value = RamHandlerSupport.class, search = SearchStrategy.CURRENT)
    public RamHandlerSupport ramHandlerSupport(RamCacheSupport ramCacheSupport) {
        return new DefaultRamHandlerSupport(ramCacheSupport);
    }

    @Bean
    @ConditionalOnBean(value = {RamCoreService.class, RamHandlerSupport.class})
    public PathPolicyHandlerComposite pathPolicyHandler(RamCoreService ramCoreService, RamHandlerSupport ramHandlerSupport) {
        return new PathPolicyHandlerComposite(ramCoreService, ramHandlerSupport, properties.isFunction());
    }

    @Bean
    @ConditionalOnBean(value = {RamCoreService.class, RamHandlerSupport.class})
    public AuthPolicyHandlerComposite authPolicyHandler(RamCoreService ramCoreService, RamHandlerSupport ramHandlerSupport) {
        return new AuthPolicyHandlerComposite(ramCoreService, ramHandlerSupport);
    }

    @Bean
    @ConditionalOnBean(value = {PathPolicyHandler.class, AuthPolicyHandler.class})
    @Conditional(IamV1Condition.class)
    public FilterRegistrationBean<Filter> ramAccessCheckRegistration(PathPolicyHandler<AccessUser> pathPolicyHandler, AuthPolicyHandler authPolicyHandler) {
        FilterRegistrationBean<Filter> registrationBean = new FilterRegistrationBean<>();
        RamV1AccessCheckFilter filter = new RamV1AccessCheckFilter(pathPolicyHandler, authPolicyHandler);
        registrationBean.setFilter(filter);
        registrationBean.setOrder(filter.getOrder());
        registrationBean.addUrlPatterns(RamConstant.DEFAULT_URL_MAPPINGS);
        registrationBean.setAsyncSupported(true);
        return registrationBean;
    }
}
